@@ -3,7 +3,7 @@ if(getRversion() < "3.3.0") setInternet2()
 
 # Download OpenSSL
 if(!file.exists("../windows/openssl-1.1.1/include/openssl/ssl.h")){
-  download.file("https://github.com/rwinlib/openssl/archive/v1.1.1.zip", "lib.zip", quiet = TRUE)
+  download.file("https://github.com/rwinlib/openssl/archive/v1.1.1k.zip", "lib.zip", quiet = TRUE)
   dir.create("../windows", showWarnings = FALSE)
   unzip("lib.zip", exdir = "../windows")
   unlink("lib.zip")
